# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Term-Table
Version:	0.024
Release:	1.%{__distinit}%{__distvers}
Summary:	Format a header and rows into a table
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Term-Table
Source0:	https://cpan.metacpan.org/modules/by-module/Term/Term-Table-%{version}.tar.gz
Patch0:		Term-Table-0.024-Use-system-Object-HashBase.patch
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Config)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(Object::HashBase) >= 0.008
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Test2::API)
BuildRequires:	perl(Test2::Tools::Tiny)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(utf8)
# Optional Tests
BuildRequires:	perl(Test2::Tools::Tiny) >= 1.302097
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Optional functionality support if we can do weak dependencies
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
# Term::Size::Any for terminal width
BuildRequires:	perl(Term::Size::Any) >= 0.002
Recommends:	perl(Term::Size::Any) >= 0.002
# Unicode::GCString for formatting double-width string
BuildRequires:	perl(Unicode::GCString) >= 2013.10
Recommends:	perl(Unicode::GCString) >= 2013.10
%if 0%{?fedora} > 21
BuildRequires:	perl(Unicode::LineBreak) >= 2015.06
Recommends:	perl(Unicode::LineBreak) >= 2015.06
%endif
%endif

%description
This module is able to generically format rows of data into tables.

%prep
%setup -q -n Term-Table-%{version}

# Unbundle Object::HashBase prior to F-41, EL-11
%if 0%{?fedora} < 41 && 0%{?rhel} < 11
%patch -P 0

# Delete bundled Object::HashBase
for F in lib/Term/Table/HashBase.pm t/HashBase.t; do
	perl -e 'unlink $ARGV[0] or die $!' "$F"
	perl -i -s -ne 'print $_ unless m{\A\Q$file\E\b}' -- -file="$F" MANIFEST
done
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Term/
%{_mandir}/man3/Term::Table.3*
%{_mandir}/man3/Term::Table::Cell.3*
%{_mandir}/man3/Term::Table::CellStack.3*
%if 0%{?fedora} >= 41 || 0%{?rhel} >= 11
%{_mandir}/man3/Term::Table::HashBase.3*
%endif
%{_mandir}/man3/Term::Table::LineBreak.3*
%{_mandir}/man3/Term::Table::Util.3*

%changelog
* Sat Dec 28 2024 Paul Howarth <paul@city-fan.org> - 0.024-1
- Update to 0.024
  - Additional changes to t/honor_env_in_non_tty.t, and adding debugging

* Sun Nov 10 2024 Paul Howarth <paul@city-fan.org> - 0.023-2
- Don't unbundle Object::HashBase from F-41 onwards (module in Perl Core)

* Sun Oct 27 2024 Paul Howarth <paul@city-fan.org> - 0.023-1
- Update to 0.023
  - t/honor_env_in_non_tty.t requires Test2::Tools::Tiny >= 1.302097; use
    Test::More if not available

* Wed Aug  7 2024 Paul Howarth <paul@city-fan.org> - 0.022-1
- Update to 0.022
  - Fix warnings in HashBase.t
  - Some initial support for non-ASCII systems

* Tue Aug  6 2024 Paul Howarth <paul@city-fan.org> - 0.020-1
- Update to 0.020
  - Fix use cycle between Test-Simple and Term::Table now that Test2::Suite was
    merged into Test-Simple
  - Fix test broken on Test::More

* Mon Oct 23 2023 Paul Howarth <paul@city-fan.org> - 0.018-1
- Update to 0.018
  - Documentation fixes (GH#17)

* Thu Sep 14 2023 Paul Howarth <paul@city-fan.org> - 0.017-1
- Update to 0.017
  - Remove 'Importer' dependency

* Sun Jul  2 2023 Paul Howarth <paul@city-fan.org> - 0.016-6
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 0.016-3
- Perl 5.36 rebuild

* Tue Jan  4 2022 Paul Howarth <paul@city-fan.org> - 0.016-1
- Update to 0.016
  - Be explicit about bareword filehandles
- Use %%license unconditionally

* Fri Nov 22 2019 Paul Howarth <paul@city-fan.org> - 0.015-2
- Unbundle Object::HashBase

* Tue Nov 19 2019 Paul Howarth <paul@city-fan.org> - 0.015-1
- Update to 0.015
  - Update inlined Object::HashBase

* Wed Oct 16 2019 Paul Howarth <paul@city-fan.org> - 0.014-1
- Update to 0.014
  - Clone STDOUT on load in case it gets changed later

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 0.013-3
- Perl 5.30 rebuild

* Wed Dec  5 2018 Paul Howarth <paul@city-fan.org> - 0.013-1
- Update to 0.013
  - Fix line break calculation hangs (GH#9)
  - Add 'pad' and 'allow_overflow' options
- Switch upstream from search.cpan.org to metacpan.org

* Thu Oct 12 2017 Paul Howarth <paul@city-fan.org> - 0.012-1
- Update to 0.012
  - Bump minimum Test2::Tools::Tiny version

* Tue Oct 10 2017 Paul Howarth <paul@city-fan.org> - 0.011-1
- Update to 0.011
  - Honour the env variable even on non-term output

* Wed Oct  4 2017 Paul Howarth <paul@city-fan.org> - 0.010-1
- Update to 0.010
  - Further optimize term_size when SIGWINCH is supported
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88

* Sun Mar 19 2017 Paul Howarth <paul@city-fan.org> - 0.008-1
- Update to 0.008
  - Remove stray line that was setting STDOUT to utf8
  - Prefer Term::Size::Any over Term::ReadKey
  - Do not use either if STDOUT is not a terminal

* Wed Jan 11 2017 Paul Howarth <paul@city-fan.org> - 0.006-1
- Update to 0.006
  - Fix rendering issue when all lines are the same length

* Thu Dec 29 2016 Paul Howarth <paul@city-fan.org> - 0.005-1
- Update to 0.005
  - Add Term::Table::Spacer

* Wed Dec 21 2016 Paul Howarth <paul@city-fan.org> - 0.004-1
- Update to 0.004
  - Add Term::Table::CellStack to represent a vertically merged cell in a table

* Tue Dec 20 2016 Paul Howarth <paul@city-fan.org> - 0.003-1
- Update to 0.003
  - Fix recommended deps

* Tue Dec 20 2016 Paul Howarth <paul@city-fan.org> - 0.002-1
- Initial RPM version
